require 'uu/os/rest/dto'
require 'uu/os/uesuri'


# Module Unicorn Universe.
module UU
  # Module Operating System.
  module OS
    # Module Activity Condition.
    module ActivityCondition
      # Attributes of the activity condition.
      class ActivityConditionAttributes < UU::OS::REST::DTO

        # Activity condition identifier. This parameter is specified only for root conditions (of all types) because
        # nested conditions are identified by the parameter "id" instead.
        attr_accessor :condition_code

        # Nested activity condition identifier. This parameter is specified only for nested conditions
        # to identify them in the parameter "expression" located on their parent (composed) condition. The value
        # of this parameter is generated automatically according to the order of conditions in condition_list
        # and also according to their types.
        attr_accessor :id

        # URI of the entity (activity instance or activity template) this activity condition is created for.
        # Never nil.
        attr_accessor :entity_uri

        # Type of the activity condition. Never nil.
        # 
        # @see UU::OS::ActivityCondition::ActivityConditionType
        attr_accessor :type

        # Validity type of the activity condition. Impulse activity condition is fulfilled when the condition
        # is met. Level activity condition is fulfilled from the time when the condition is met and subsequently
        # throughout the given condition existence. This parameter is specified in all conditions except composed
        # conditions.
        # 
        # @see UU::OS::ActivityCondition::ActivityConditionValidityType
        attr_accessor :validity_type

        # Date of fulfilling of the time condition. Specified only for time conditions.
        attr_accessor :date_of_fulfilling

        # Specifies whether the condition will be executed every time when the given conditions are fulfilled
        # or it will be transformed into a simple time condition after its first evaluation. This parameter
        # is specified only for artifact state or activity state conditions.
        attr_accessor :recurring

        # Specifies the duration which must be elapsed for condition fulfillment. This parameter is specified
        # only for artifact state or activity state conditions.
        attr_accessor :delay

        # URI of an artifact state template. The condition is fulfilled when the related artifact is set
        # to the state specified by this template. This parameter is specified only for artifact state conditions.
        attr_accessor :artifact_state_template_uri

        # URI of an artifact state template. The condition where this parameter is specified is fulfilled only
        # if the related artifact was set to the state specified by this template right before it was set
        # into the state specified in artifact_state_template_uri. This parameter is specified only for artifact
        # state conditions.
        attr_accessor :previous_artifact_state_template_uri

        # URI of an activity state template. The condition is fulfilled when an activity instance created
        # according to the related activity template is set to the state specified by this activity state
        # template. This parameter is specified only for activity state conditions.
        attr_accessor :activity_state_template_uri

        # URI of an activity state template. The condition that uses this parameter is fulfilled only when
        # an activity instance created according to the related activity template was set to the state specified
        # by this template right before it was set into the state specified in activity_state_template_uri.
        # This parameter is specified only for activity state conditions.
        attr_accessor :previous_activity_state_template_uri

        # Logical expression of the composed activity condition that describes logical relationships among nested
        # conditions. Nested conditions are represented by their values that can be found in their parameters "id".
        attr_accessor :expression

        # The list of nested conditions of the composed activity condition. The order of conditions in this list
        # corresponds to their occurrence in the parameter "expression".
        attr_accessor :condition_list
        
        def condition_code
           attributes[:conditionCode]
        end
        
        def condition_code=(val)           
           attributes[:conditionCode] = val 
        end         
       
        def id
           attributes[:id]
        end
       
        def id=(val)
           attributes[:id] = val
        end
        
        def entity_uri
           attributes[:entityUri]
        end
        
        def entity_uri=(val)
           if val
              attributes[:entityUri] = UU::OS::UESURI.new(val)
           else
              attributes[:entityUri] = nil
           end
        end
        
        def type
           attributes[:type]
        end
             
        def type=(val)
           attributes[:type] = val
        end
        
        def validity_type
           attributes[:validityType]
        end
                
        def validity_type=(val)           
           attributes[:validityType] = val 
        end
        
        def date_of_fulfilling
           attributes[:dateOfFulfilling]
        end
               
        def date_of_fulfilling=(val)
           attributes[:dateOfFulfilling] = val
        end
        
        def recurring
           attributes[:recurring]
        end
              
        def recurring=(val)
           attributes[:recurring] = val
        end

        def delay
           attributes[:delay]
        end
              
        def delay=(val)
           attributes[:delay] = val
        end        
        
        def artifact_state_template_uri
           attributes[:artifactStateTemplateUri]
        end
        
        def artifact_state_template_uri=(val)
           if val
              attributes[:artifactStateTemplateUri] = UU::OS::UESURI.new(val)
           else
              attributes[:artifactStateTemplateUri] = nil
           end
        end
        
        def previous_artifact_state_template_uri
            attributes[:previousArtifactStateTemplateUri]
        end
                
        def previous_artifact_state_template_uri=(val)
             if val
                attributes[:previousArtifactStateTemplateUri] = UU::OS::UESURI.new(val)
             else
                attributes[:previousArtifactStateTemplateUri] = nil
             end
         end
        
        
        def activity_state_template_uri
             attributes[:activityStateTemplateUri]
        end
               
        def activity_state_template_uri=(val)
           if val
              attributes[:activityStateTemplateUri] = UU::OS::UESURI.new(val)
           else
              attributes[:activityStateTemplateUri] = nil
           end
        end
        
        def previous_activity_state_template_uri
              attributes[:previousActivityStateTemplateUri]
        end
                       
        def previous_activity_state_template_uri=(val)
            if val
              attributes[:previousActivityStateTemplateUri] = UU::OS::UESURI.new(val)
            else
              attributes[:previousActivityStateTemplateUri] = nil
            end
        end
        
        def expression
           attributes[:expression]
        end
               
        def expression=(val)
           attributes[:expression] = val
        end
        
        def condition_list
           attributes[:conditionList]
        end
               
        def condition_list=(val)           
           attributes[:conditionList] = val 
        end 

      end
    end

  end
end